/* This file is part of David Deaven's personal library.
 * Copyright (c) 1994 David Deaven
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: geomopac.c,v 1.2 1995/10/10 14:49:18 deaven Exp $
 */

#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include "dmd/geometry.h"
#include "dmd/memory.h"

char *usage = "usage: %s <options> [geometry]\n"
  "options:\n"
  "\t-o fn        set output file\n"
  "\t-k keys      specify MOPAC keywords\n"
  "\t-M           read MOPAC output, not geometry; write geometry\n"
  ;

int main(int argc, char **argv)
{
	int arg;
	int init = 1;
	int Mflag = 0;
	Geometry *g;
	char *keys = "1SCF";
	char *ifn = "-", *ofn = "-";
	FILE *fin, *fout;

	for(arg=1; arg<argc; ++arg)
	  if(argv[arg][0] == '-')
	    switch(argv[arg][1])
	    {
	      case 'o':
		ofn = argv[++arg];
		break;

	      case 'k':
		keys = argv[++arg];
		break;

	      case 'M':
		Mflag = 1;
		break;

	      default:
	      	fprintf(stderr, usage, argv[0]);
	      	exit(1);
	    }
	  else
	    ifn = argv[arg];

	fin = (strcmp(ifn, "-") == 0 ? stdin : fopen(ifn, "r"));
	if(fin == NULL)
	{
		fprintf(stderr, "%s: cannot open %s\n", argv[0], ifn);
		exit(1);
	}

	fout = (strcmp(ofn, "-") == 0 ? stdout : fopen(ofn, "w"));
	if(fout == NULL)
	{
		fprintf(stderr, "%s: cannot open %s\n", argv[0], ofn);
		exit(1);
	}

	if(Mflag)
	{
	  g = GreadMPCOutput(fin);
	  Gfree(g);
	  g = GreadMPCOutput(fin);
	  GprintXYZ(fout, g);
	  Gfree(g);
	}
	else
	{
	  while((g = Gread(fin)) != NULL)
	  {
	    if(init) {
	      fprintf(fout, "XYZ %s\n%s\nCreated by %s from `%s'\n",
		keys, g->name, argv[0], ifn);
	      init = 0;
	    }
	    GprintMPC(fout, g);
	    Gfree(g);
	  }
	}

	if(fin != stdin) fclose(fin);
	if(fout != stdout) fclose(fout);

	return 0;
}
